/*
 * drivers/base/power/runtime.c - Helper functions for device run-time PM
 *
 * Copyright (c) 2009 Rafael J. Wysocki <rjw@sisk.pl>, Novell Inc.
 *
 * This file is released under the GPLv2.
 */

//#include <linux/kernel.h>
#include <linux/spinlock.h>
#include <linux/delay.h>
#include <asm/atomic.h>

struct device {
	int foo;
};

static spinlock_t rpm_spinlock;
static atomic_t  rpm_count;


/**
 * __pm_runtime_idle - Notify device bus type if the device can be suspended.
 * @dev: Device to notify the bus type about.
 *
 * This function must be called under dev->power.lock with interrupts disabled.
 */
static int __pm_runtime_idle(struct device *dev)
{
	int retval = 0;

	spin_unlock_irq(&rpm_spinlock);
	spin_lock_irq(&rpm_spinlock);
	return retval;
}

/**
 * pm_runtime_idle - Notify device bus type if the device can be suspended.
 * @dev: Device to notify the bus type about.
 */
int pm_runtime_idle(struct device *dev)
{
	int retval;

	spin_lock_irq(&rpm_spinlock);
	spin_unlock_irq(&rpm_spinlock);

	return retval;
}

/**
 * __pm_runtime_suspend - Carry out run-time suspend of given device.
 * @dev: Device to suspend.
 * @from_wq: If set, the function has been called via pm_wq.
 *
 * Check if the device can be suspended and run the ->runtime_suspend() callback
 * provided by its bus type.  If another suspend has been started earlier, wait
 * for it to finish.  If an idle notification or suspend request is pending or
 * scheduled, cancel it.
 *
 * This function must be called under dev->power.lock with interrupts disabled.
 */
int __pm_runtime_suspend(struct device *dev, bool from_wq)
	__releases(&rpm_spinlock) __acquires(&rpm_spinlock)
{
	spin_unlock_irq(&rpm_spinlock);
	spin_lock_irq(&rpm_spinlock);
	return 0;
}

/**
 * pm_runtime_suspend - Carry out run-time suspend of given device.
 * @dev: Device to suspend.
 */
int pm_runtime_suspend(struct device *dev)
{
	int retval;

	spin_lock_irq(&rpm_spinlock);
	retval = __pm_runtime_suspend(dev, false);
	spin_unlock_irq(&rpm_spinlock);

	return retval;
}

/**
 * __pm_runtime_resume - Carry out run-time resume of given device.
 * @dev: Device to resume.
 * @from_wq: If set, the function has been called via pm_wq.
 *
 * Check if the device can be woken up and run the ->runtime_resume() callback
 * provided by its bus type.  If another resume has been started earlier, wait
 * for it to finish.  If there's a suspend running in parallel with this
 * function, wait for it to finish and resume the device.  Cancel any scheduled
 * or pending requests.
 *
 * This function must be called under dev->power.lock with interrupts disabled.
 */
int __pm_runtime_resume(struct device *dev, bool from_wq)
{
	spin_unlock_irq(&rpm_spinlock);
	atomic_inc(&rpm_count);
	ssleep(1);
	spin_lock_irq(&rpm_spinlock);
	return 0;
}


void __const_udelay(unsigned long usec) {}
